@@ -22,7 +22,7 @@
 #include "ldapsearch.h"
 
 #include <QProgressDialog>
-#include <kcombobox.h>
+#include <QComboBox>
 #include "ldap_debug.h"
 #include <klocalizedstring.h>
 #include <klineedit.h>
@@ -239,9 +239,13 @@ void LdapConfigWidget::Private::initWidget()
         //without host query doesn't make sense
         if (mHost) {
             QPushButton *dnquery = new QPushButton(i18n("Query Server"), mParent);
+            dnquery->setEnabled(false);
             connect(dnquery, &QPushButton::clicked, mParent, [this]() {
                 queryDNClicked();
             });
+            connect(mDn, &QLineEdit::textChanged, mParent, [dnquery](const QString &text) {
+                dnquery->setEnabled(!text.trimmed().isEmpty());
+            });
             mainLayout->addWidget(dnquery, row, 2, 1, 1);
         }
         row++;
